@@ -9,7 +9,6 @@ import re
 __all__ = (
     'has_unclosed_brackets',
     'get_jedi_script_from_document',
-    'current_python_buffer',
     'document_is_multiline_python',
 )
 
@@ -49,10 +48,6 @@ def get_jedi_script_from_document(document, locals, globals):
             line=document.cursor_position_row + 1,
             path='input-text',
             namespaces=[locals, globals])
-
-    except jedi.common.MultiLevelStopIteration:
-        # This happens when the document is just a backslash.
-        return None
     except ValueError:
         # Invalid cursor position.
         # ValueError('`column` parameter is not in a valid range.')
@@ -69,18 +64,6 @@ def get_jedi_script_from_document(document, locals, globals):
         return None
 
 
-def current_python_buffer(cli, python_settings):
-    """
-    Return the name of the current Python input buffer.
-
-    Returns (name, buffer_instance) tuple.
-    """
-    for name in [cli.focus_stack.current, cli.focus_stack.previous]:
-        if name is not None and name.startswith('python-'):
-            return name, cli.buffers[name]
-    return None, None
-
-
 _multiline_string_delims = re.compile('''[']{3}|["]{3}''')
 
 
